# $Id: aclocal.m4,v 1.12 2007/12/21 02:50:42 zlb Exp $

#--------------------------------------- Autoconf macros

#
# AC_ADD_FLAGS(varname, new flags)
#
AC_DEFUN(AC_ADD_FLAGS, [dnl
    for ac_i in $2; do
	if test "$ac_i" = "-I/usr/include" -o "$ac_i" = "-L/usr/lib"; then
	    continue
	fi
	if ! echo " ${$1} " | grep " $ac_i " >/dev/null; then
	    $1="${$1} $ac_i"
	    continue
	fi
    done dnl
])

#
# AC_ADD_LIBS(varname, new libs[, append_flag])
#
AC_DEFUN(AC_ADD_LIBS, [dnl
    ac_tmp=""
    for ac_i in $2; do
	# always keep '-lxxx'
	if test "$ac_i" != "`echo $ac_i | sed -e 's/^-l//'`"; then
	    ac_tmp="$ac_tmp $ac_i"
	    continue
	fi
	# always keep non-option items
	# Warning: this breaks cases like '-Ldira -lxxx -Ldirb -lxxx'
	if test "$ac_i" = "`echo $ac_i | sed -e 's/^-//'`"; then
	    ac_tmp="$ac_tmp $ac_i"
	    continue
	fi
	if ! echo " ${$1} " " $ac_tmp " | grep " $ac_i " >/dev/null; then
	    ac_tmp="$ac_tmp $ac_i"
	    continue
	fi
    done
    if test -n "$ac_tmp"; then
	if test "$3" = "append"; then
	    # append new libs
	    $1="${$1} $ac_tmp"
	else
	    # prepend new libs
	    $1="$ac_tmp ${$1}"
	fi
    fi dnl
])

#
# AC_FIND_HEADER(var_name, dirs, dirname_pattern, header_name)
#
AC_DEFUN(AC_FIND_HEADER, [dnl
    if test x"${$1}" = x; then
	for ac_d in $2 /usr/include/$3 /usr/$3/include dnl
		 /opt/include /opt/include/$3 /opt/$3/include dnl
		 /usr/local/include /usr/local/include/$3 /usr/local/$3/include
	do
	    for ac_f in ${ac_d}/$4.h; do
		if test -r "${ac_f}"; then
		    $1="`dirname ${ac_f}`"
		    break
		fi
	    done
	    if test x"${$1}" != x; then break; fi
	done
    fi dnl
])

#
# AC_CHECK_FORTRAN(code, ret)
#
AC_DEFUN(AC_CHECK_FORTRAN, [dnl
    AC_LINK_IFELSE([$1], $2_ok=yes, $2_ok=no)
    if test "${$2_ok}" != "yes"; then
	LIBS_forbak="${LIBS}"
	AC_ADD_LIBS(LIBS, ${FCLIBS}, append)
	AC_LINK_IFELSE([$1], $2_ok=yes, $2_ok=no)
	if test "${$2_ok}" != "yes"; then
	    LIBS="${LIBS_forbak}"
	    AC_ADD_LIBS(LIBS, ${FLIBS}, append)
	    AC_LINK_IFELSE([$1], $2_ok=yes, $2_ok=no)
	fi
	if test "${$2_ok}" != "yes"; then
	    LIBS="${LIBS_forbak}"
	fi
    fi
])

#
# AC_FIND_LIB(name, dirs, dirname_pattern, libname, testprog)
#
AC_DEFUN(AC_FIND_LIB, [dnl
    if test x"${with_$1_lib}" = x; then
	ac_flag=false
	for ac_d in $2 /usr/lib* /usr/lib*/$3 /usr/$3/lib* dnl
		    /opt/lib* /opt/lib*/$3 /opt/$3/lib* dnl
		    /usr/local/lib* /usr/local/lib*/$3 /usr/local/$3/lib*
	do
	    for ac_f in ${ac_d}/lib$4.so ${ac_d}/lib$4.a; do
		if test -r "${ac_f}"; then
		    with_$1_lib="${with_$1_lib} ${ac_f}"
		fi
	    done
	done
    else
	ac_flag=true
    fi
    CPPFLAGS_findbak="${CPPFLAGS}"
    LDFLAGS_findbak="${LDFLAGS}"
    LIBS_findbak="${LIBS}"
    if test x"${with_$1_incdir}" != x; then
	AC_ADD_FLAGS(CPPFLAGS, -I$with_$1_incdir)
    fi
    for ac_lib in "" ${with_$1_lib}; do
	if ${ac_flag}; then
	    LIBS="${with_$1_lib} $LIBS_findbak"
	elif test x$ac_lib != x; then
	    dnl ac_base="`echo ${ac_lib} | sed -e 's|.*/||'`"
	    dnl ac_dir="`echo ${ac_lib} | sed -e \"s|/${ac_base}||\"`"
	    dnl if test "$ac_dir" = "$ac_base"; then ac_dir=""; fi
	    ac_base="`basename ${ac_lib}`"
	    ac_dir="`dirname ${ac_lib}`"
	    if test x$ac_dir != x; then
		if ! echo " $LDLAGS " | grep ' '$ac_dir' ' >/dev/null; then
		    LDFLAGS="$LDFLAGS_findbak"
		    AC_ADD_FLAGS(LDFLAGS, -L${ac_dir})
		fi
	    fi
	    ac_base=`echo $ac_base | dnl
			sed -e 's/^lib//' -e 's/\.a$//' -e 's/\.so$//'`
	    LIBS="-l${ac_base} ${LIBS_findbak}"
	else
	    LIBS="${LIBS_findbak}"
	fi
	AC_LINK_IFELSE([$5], enable_$1=yes, enable_$1=no)
	if ${ac_flag}; then break; fi
	if test ${enable_$1} != no; then
	    with_$1_lib=${ac_lib}
	    break
	fi
    done
    if test ${enable_$1} = no; then
	LIBS="${LIBS_findbak}"
	LDFLAGS="${LDFLAGS_findbak}"
	CPPFLAGS="${CPPFLAGS_findbak}"
    fi dnl
])
